@@ -167,7 +167,7 @@ class CreateMailProfileRequest(AbstractModel):
         :type ProfileType: str
         :param Product: 服务产品类型，支持值包括： "mysql" - 云数据库 MySQL， "cynosdb" - 云数据库 CynosDB  for MySQL。
         :type Product: str
-        :param BindInstanceIds: 配置绑定的实例ID，当配置级别为"Instance"时需要传入，只能为一个实例。
+        :param BindInstanceIds: 配置绑定的实例ID，当配置级别为"Instance"时需要传入且只能为一个实例；当配置级别为“User”时，此参数不填。
         :type BindInstanceIds: list of str
         """
         self.ProfileInfo = None
@@ -361,7 +361,7 @@ class DescribeAllUserContactRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: 服务产品类型，支持值包括： "mysql" - 云数据库 MySQL， "cynosdb" - 云数据库 CynosDB  for MySQL。
+        :param Product: 服务产品类型，固定值：mysql。
         :type Product: str
         :param Names: 联系人名数组，支持模糊搜索。
         :type Names: list of str
@@ -413,7 +413,7 @@ class DescribeAllUserGroupRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: 服务产品类型，支持值包括： "mysql" - 云数据库 MySQL， "cynosdb" - 云数据库 CynosDB  for MySQL。
+        :param Product: 服务产品类型，固定值：mysql。
         :type Product: str
         :param Names: 联系组名称数组，支持模糊搜索。
         :type Names: list of str
